import os
from time import time

import pandas as pd
from ..tools.tools import Tools


class Teams():
    """
        Team class to get all NBA teams informations and details
    """
    def __init__(self, url):
        self.tools = Tools(url)
        self.data_url = url
        
    def export_teams(self):
        """
            Function to export teams into csv file
            TODO :
                Url season setup to get data
        """
        try:
            # Initialize the timer
            t0 = time()
            # Url of the all team detailes per seasons
            url = 'https://stats.nba.com/stats/leaguedashteamstats?Conference=&DateFrom=&DateTo=&Division=&GameScope=&GameSegment=&LastNGames=0&LeagueID=00&Location=&MeasureType=Base&Month=0&OpponentTeamID=0&Outcome=&PORound=0&PaceAdjust=N&PerMode=Totals&Period=0&PlayerExperience=&PlayerPosition=&PlusMinus=N&Rank=N&Season=2021-22&SeasonSegment=&SeasonType=Regular+Season&ShotClockRange=&StarterBench=&TeamID=0&TwoWay=0&VsConference=&VsDivision='
            teams = self.tools.get_data(url, datasets_name=['LeagueDashTeamStats'])
            teams = teams['LeagueDashTeamStats']
            teams_clean = self.__get_team_info(teams)
            
            if teams_clean is not None:
                teams_clean.to_csv(self.data_url + 'teams.csv')
                
            print('Export all Teams execution time : %.2fs'%(time()-t0))
            
        except Exception as e:
            raise e
        
    def export_team_detail(self):
        """
            Function to export teams detailes into csv file
            Concat with the teams dataset with the actual team detaile dataset
        """
        try:
            # Initialize the timer
            t0 = time()
            teams = self.__get_team()
            # Extract the season scoreboard per team
            teams_detail = teams['TEAM_ID'].apply(lambda x: self.__get_team_detail(x))
            
            # Concat teams details dataset values
            teams_detail = pd.concat(teams_detail.values)
            
            if teams_detail is not None:
                teams_detail.to_csv(self.data_url + 'teams_details.csv')
                
            print('Export Teams details execution time : %.2fs'%(time()-t0))
            
        except Exception as e:
            # TODO Put a print() to replace the raise
            raise e
        
    def __get_team_detail(self, team_id: int):
        """
            Private function return the Team scoreboard Year by Year 
            Pandas dataFrame with a new columnn TEAM_ID
            TODO :
                Url season setup to get data
        """
        try:
            # Url of the Team scoreboard year by year
            team_detail_url = 'https://stats.nba.com/stats/teamdashboardbyyearoveryear?DateFrom=&DateTo=&GameSegment=&LastNGames=0&LeagueID=00&Location=&MeasureType=Base&Month=0&OpponentTeamID=0&Outcome=&PORound=0&PaceAdjust=N&PerMode=Totals&Period=0&PlusMinus=N&Rank=N&Season=2021-22&SeasonSegment=&SeasonType=Regular+Season&ShotClockRange=&Split=yoy&TeamID='+ str(team_id) +'&VsConference=&VsDivision='
            df = self.tools.get_data(team_detail_url, datasets_name=['ByYearTeamDashboard'])
            # Add column into current team detail dataset
            df['ByYearTeamDashboard']['TEAM_ID'] = team_id
            # return team detaile dataset with the TEAM_ID column
            return df['ByYearTeamDashboard']
        except Exception as e:
            raise e
    
    def __get_team(self):
        """
            Return Teams infomations
        """
        try:
            # Url of the all team detailes per seasons
            url = 'https://stats.nba.com/stats/leaguedashteamstats?Conference=&DateFrom=&DateTo=&Division=&GameScope=&GameSegment=&LastNGames=0&LeagueID=00&Location=&MeasureType=Base&Month=0&OpponentTeamID=0&Outcome=&PORound=0&PaceAdjust=N&PerMode=Totals&Period=0&PlayerExperience=&PlayerPosition=&PlusMinus=N&Rank=N&Season=2021-22&SeasonSegment=&SeasonType=Regular+Season&ShotClockRange=&StarterBench=&TeamID=0&TwoWay=0&VsConference=&VsDivision='
            teams = self.tools.get_data(url, datasets_name=['LeagueDashTeamStats'])
            return teams['LeagueDashTeamStats']
        except Exception as e:
            raise e
    
    def __get_team_info(self, teams_dataset):
        """
            Return Team info dataset
        """
        try:
            # Url to get Teams infos 
            url = 'https://stats.nba.com/stats/commonteamyears?LeagueID=00'
            teams = self.tools.get_data(url, datasets_name=['TeamYears'])
            teams = teams['TeamYears']
            # Add column ABBREVIATION to the dataset
            teams_dataset["ABBREVIATION"] = teams_dataset.merge(teams, on="TEAM_ID")["ABBREVIATION"]
            # Add column YEARFOUNDED to the dataset
            teams_dataset['YEARFOUNED'] = teams_dataset.merge(teams, on="TEAM_ID")['MIN_YEAR']

            return teams_dataset
        except Exception as e:
            raise e
    

# NBA Url for team lineup
# https://stats.nba.com/stats/leaguedashlineups?Conference=&DateFrom=&DateTo=&Division=&GameID=&GameSegment=&GroupQuantity=5&LastNGames=0&LeagueID=00&Location=&MeasureType=Base&Month=0&OpponentTeamID=0&Outcome=&PORound=0&PaceAdjust=N&PerMode=Totals&Period=0&PlusMinus=N&Rank=N&Season=2021-22&SeasonSegment=&SeasonType=Regular+Season&ShotClockRange=&TeamID=0&VsConference=&VsDivision=

# NBA Url for teams stats per season
# https://stats.nba.com/stats/leaguedashteamstats?Conference=&DateFrom=&DateTo=&Division=&GameScope=&GameSegment=&LastNGames=0&LeagueID=00&Location=&MeasureType=Base&Month=0&OpponentTeamID=0&Outcome=&PORound=0&PaceAdjust=N&PerMode=Totals&Period=0&PlayerExperience=&PlayerPosition=&PlusMinus=N&Rank=N&Season=2021-22&SeasonSegment=&SeasonType=Regular+Season&ShotClockRange=&StarterBench=&TeamID=0&TwoWay=0&VsConference=&VsDivision=

# NBA Url for Team scorboard per season
# https://stats.nba.com/stats/leaguegamelog?Counter=1000&DateFrom=&DateTo=&Direction=DESC&LeagueID=00&PlayerOrTeam=T&Season=2021-22&SeasonType=Regular+Season&Sorter=DATE




import requests
from time import sleep


class Scrapper():
    """
    Class to simplify scrapping on website and API.

    """
    HEADER = {
        'Host': 'stats.nba.com',
        'User-Agent': 'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:70.0) Gecko/20100101 Firefox/70.0',
        'Referer': 'https://www.nba.com/stats/',
        'Origin': 'https://www.nba.com',
        'Accept': '*/*',
        'Accept-Language': 'en-GB,en;q=0.5',
        'Accept-Encoding': 'gzip, deflate, br',
        'DNT': '1',
        'Connection': 'keep-alive',
        'Pragma': 'no-cache',
        'Cache-Control': 'no-cache',
        'Upgrade-Insecure-Requests': '1',
    }

    def __init__(self, max_call_errors=None):
        self.max_call_errors = max_call_errors

    def repeat_call_while_error(self, url):
        response = requests.get(url, headers=self.HEADER)
        errors_cnt = 0
        while not response.status_code != 200 & errors_cnt < self.max_call_errors:
            sleep(1)
            errors_cnt += 1
            response = requests.get(url, headers=self.HEADER)

        if errors_cnt == self.max_call_errors:
            return None

        return response

    def call_url(self, url):
        self.HEADER['Referer'] = url
        
        response = requests.get(url, headers=self.HEADER)

        if response.status_code != 200:
            if self.max_call_errors != None:
                response = self.repeat_call_while_error(url=url)

            if response == None:
                return None

        return response

    def retrieve_json_api_from_url(self, url):
        response = self.call_url(url=url)

        if response == None:
            return None

        if response.status_code != 200:
            print('Error code : %i'%response.status_code)
            return None

        return response.json()



import datetime
import os
from time import sleep, time

import joblib
import pandas as pd
from ..tools.preformator import Preformator
from ..tools.tools import Tools


class Games():
    """
        Games class to get all NBA stats and ranking
    """
    def __init__(self, url):
        self.tools = Tools(url)
        self.data_url = url
        
    def next_week_games(self):
        """
            Get next week games
        """
        try:
            # Initialize the timer
            t0 = time()
            
            for i in range(1,8):
                date = self.tools.get_date(i,"+")
                url = 'https://stats.nba.com/stats/scoreboardV2?DayOffset=0&LeagueID=00&gameDate='+date
                games = self.tools.get_data(url, datasets_name=['GameHeader'])
                games = games['GameHeader']
                
                if games is not None:
                    games.to_csv(self.data_url + 'daily/games_'+ date +'.csv')
                    
            print('Next week Teams export execution time : %.2fs'%(time()-t0))
        except Exception as e:
            raise e
        
    def last_week_games(self):
        """
            Get last week games
        """
        try:
            # Initialize the timer
            t0 = time()
            
            for i in range(1,8):
                date = self.tools.get_date(i,"-")
                url = 'https://stats.nba.com/stats/scoreboardV2?DayOffset=0&LeagueID=00&gameDate='+date
                games = self.tools.get_data(url, datasets_name=['GameHeader'])
                games = games['GameHeader']
                
                if games is not None:
                    games.to_csv(self.data_url + 'daily/games_'+ date +'.csv')
                    
            print('Last week games export execution time : %.2fs'%(time()-t0))
        except Exception as e:
            raise e

    def today_games(self):
        """
            Get Today games
        """
        try:
            # Initialize the timer
            t0 = time()
            
            date = datetime.date.today().strftime('%Y-%m-%d')
            url = 'https://stats.nba.com/stats/scoreboardV2?DayOffset=0&LeagueID=00&gameDate='+date
            games = self.tools.get_data(url, datasets_name=['GameHeader'])
            games = games['GameHeader']
            
            if games is not None:
                games.to_csv(self.data_url + 'daily/games_'+ date +'.csv')
                    
            print('Today games export execution time : %.2fs'%(time()-t0))
        except Exception as e:
            raise e
    
    def new_games(self):
        """
            Get games and ranking data and update old datasets
        """
        t0 = time()
        try:
            # Load old datasets
            old_games = pd.read_csv(self.data_url + 'games.csv')
            old_ranking = pd.read_csv(self.data_url + 'ranking.csv')
            old_games_details = pd.read_csv(self.data_url + 'games_details.csv')
        except Exception as e:
            raise e(
                'games.csv should be in the data/ directory, if you don\'t have the current games.csv.'
            )

        max_date = old_games['GAME_DATE_EST'].max()
        
        if max_date == self.tools.get_date(1):
            print('Last update is yesterday : end script now.')
            return

        print('Last updated date : ', str(max_date))

        # Dataset to retrieve from api
        datasets = [
            'GameHeader', 'LineScore', 'EastConfStandingsByDay',
            'WestConfStandingsByDay'
        ]
        ignore_keys = ['date']

        # init dictionnary to collect data
        dfs = {}
        for dataset in datasets + ignore_keys:
            dfs[dataset] = list()

        # Be sure this file is the save of the current run
        save_path = 'games.sav'
        if os.path.exists(save_path):
            dfs = joblib.load(save_path)
            min_date_already_saved = min(dfs['date'])
        else:
            min_date_already_saved = '2100-01-01'

        # Use a for loop to avoid while(True) infinite loop
        for i in range(1, 10000):
            date = self.tools.get_date(i,"-")

            if date <= max_date:
                break
            elif date >= min_date_already_saved:
                continue

            url = 'https://stats.nba.com/stats/scoreboardV2?DayOffset=0&LeagueID=00&gameDate=' + date

            game_day_dfs = self.tools.get_data(url=url, datasets_name=datasets)
            game_day_dfs['date'] = date
            sleep(0.2)

            print('There are %i games this day' % len(game_day_dfs['GameHeader']))

            for dataset in game_day_dfs.keys():
                dfs[dataset].append(game_day_dfs[dataset])

            joblib.dump(dfs, save_path)

        # convert to pandas DataFrame
        for dataset in dfs.keys():
            if dataset in ignore_keys:
                continue
            dfs[dataset] = pd.concat(dfs[dataset])
            print(dataset, dfs[dataset].shape)

        header_cols = [
            'GAME_DATE_EST', 'GAME_ID', 'GAME_STATUS_TEXT', 'HOME_TEAM_ID',
            'VISITOR_TEAM_ID', 'SEASON'
        ]
        linescore_cols = [
            'GAME_ID', 'TEAM_ID', 'PTS', 'FG_PCT', 'FT_PCT', 'FG3_PCT', 'AST',
            'REB'
        ]

        # Get wanted datasets with wanted columns
        west_ranking = dfs['WestConfStandingsByDay']
        east_ranking = dfs['EastConfStandingsByDay']
        games_header = dfs['GameHeader'][header_cols]
        line_score = dfs['LineScore'][linescore_cols]

        del dfs

        # Preformat NBA data
        print('Preformat nba data')
        preformater = Preformator(
            games_header, line_score, west_ranking, east_ranking,self.data_url)
        new_games = preformater.preformat_games()
        new_ranking = preformater.preformat_ranking()

        del games_header, line_score, west_ranking, east_ranking

        dfs_details = list()

        # Be sure this file is the save of the current run
        save_details_path = 'games_details.sav'
        game_details_already_saved = []

        if os.path.exists(save_details_path):
            dfs_details = joblib.load(save_details_path)
            game_details_already_saved = pd.concat(dfs_details)['GAME_ID'].unique()

        # Retrieve game detail
        print('Retrieve new games details, # of games to get : ',
            str(len(new_games['GAME_ID'])))
        for game_id in new_games['GAME_ID']:
            if game_id in game_details_already_saved:
                continue

            df = self.__get_game_detail(game_id)
            if len(df) == 0:
                print('No data found')

            dfs_details.append(df)

            joblib.dump(dfs_details, save_details_path)
            
        if dfs_details is not None:
            new_games_details = pd.concat(dfs_details)

            # Merge old and new dataframe
            print('Merging old and new datasets')
            ranking = self.tools.merge_news_old(new_ranking, old_ranking)
            games = self.tools.merge_news_old(new_games, old_games)
            games_details = self.tools.merge_news_old(new_games_details, old_games_details)

            games['GAME_ID'] = pd.to_numeric(games['GAME_ID'])
            games['GAME_DATE_EST'] = pd.to_datetime(games['GAME_DATE_EST'])
            games_details['GAME_ID'] = pd.to_numeric(games_details['GAME_ID'])
            ranking['STANDINGSDATE'] = pd.to_datetime(ranking['STANDINGSDATE'])

            # Save merge datasets
            print('Save new datasets to csv into ', self.data_url)
            today = self.tools.get_date(0)
            games.to_csv(self.data_url + 'games.csv', index=False)
            games_details.to_csv(self.data_url + 'games_details.csv', index=False)
            ranking.to_csv(self.data_url + 'ranking.csv', index=False)
        
            print('Delete tmp saved files')
            os.remove(save_path)
            os.remove(save_details_path)
        else:
            print("Games and Ranking already up to date")
            os.remove(save_path)
    
    def __get_game_detail(self, game_id):
        """
            Get game details
            TODO :
                Url season setup to get data
        """
        if type(game_id) != type(str()):
            game_id = '00' + str(game_id)

        url = 'https://stats.nba.com/stats/boxscoretraditionalv2?EndPeriod=10&EndRange=0&GameID='+str(game_id) \
            + '&RangeType=0&Season=2021-22&SeasonType=Regular+Season&StartPeriod=1&StartRange=0'

        df = self.tools.get_data(url, datasets_name=['PlayerStats'])
        sleep(0.2)
        return df['PlayerStats']



import datetime
from time import sleep

import pandas as pd

from ..tools.Scrapper import Scrapper


class Tools():
    """
        Scrapper toolbox
    """
    def __init__(self, url):
        self.data_url = url
        self.scrapper = Scrapper(max_call_errors=6)
        
    def get_data(self, url, datasets_name):
        """
            Extract data from request url
            Return pandas dataFrame
        """
        json = self.scrapper.retrieve_json_api_from_url(url=url)

        if json == None:
            return None

        dfs = {}
        for elem in json['resultSets']:
            if elem['name'] not in datasets_name:
                continue

            df = pd.DataFrame(elem['rowSet'], columns=elem['headers'])
            dfs[elem['name']] = df

        return dfs
    
    def get_date(self, days: int, variation="-"):
        """
            Get the date with the delta specified
            return today() + or - days
        """
        if variation == "-":
            date = datetime.date.today() - datetime.timedelta(days=days)
        elif variation == "+":
            date = datetime.date.today() + datetime.timedelta(days=days)
        else:
            print("")
            
        return date.strftime('%Y-%m-%d')
    
    def merge_news_old(self, new_df, old_df):
        """
            Merge orld dataset with new dataset provided
        """
        return pd.concat([new_df, old_df], sort=False).drop_duplicates().reset_index(drop=True)
    
    def check_dataset(self):
        """
            Check all new informations on Games datasets
        """
        datasets = ['games.csv','games_details.csv']
        games = pd.read_csv(self.data_url + 'games.csv')

        print('====== GAMES ======')
        print(games.shape)
        print('Min date : %s'%(games['GAME_DATE_EST'].min()))
        print('Max date : %s'%(games['GAME_DATE_EST'].max()))

        games_details = pd.read_csv(self.data_url + 'games_details.csv')
        print('====== GAMES DETAILS ======')
        print(games_details.shape)
        print('N uniques games ID : %i'%(games_details['GAME_ID'].nunique()))



import pandas as pd
import numpy as np

class Preformator():
    """
    Preformater Games and ranking data after extract on the nba stats api.

    """
    def __init__(self, games_header, line_score, west_ranking, east_ranking, path):
        self.path = path
        self.games_header = games_header
        self.line_score = line_score
        self.west_ranking = west_ranking
        self.east_ranking = east_ranking
        self.teams = pd.read_csv(self.path + 'teams.csv')

    def merge_on_team(self, df, team_col):
        return df.merge(self.line_score,
                        how='inner',
                        left_on=['GAME_ID', team_col],
                        right_on=['GAME_ID', 'TEAM_ID'],
                        suffixes=('_home', '_away'))

    def home_team_win(self, df):
        return np.where(df['PTS_home'] > df['PTS_away'], 1, 0)

    def format_game_id(self, df):
        return df['GAME_ID'].apply(lambda x: '00'+str(x))

    def format_date(self, df):
        return pd.to_datetime(df['GAME_DATE_EST'])

    def filter_game_no_nba_team(self, df):
        teams_id_nba = self.teams['TEAM_ID'].unique()
        home_team_is_nba = df['HOME_TEAM_ID'].apply(
            lambda x: x in teams_id_nba)
        away_team_is_nba = df['VISITOR_TEAM_ID'].apply(
            lambda x: x in teams_id_nba)

        return df[(home_team_is_nba) & (away_team_is_nba)]

    def only_finished_game(self, df):
        return df[df['GAME_STATUS_TEXT'] == 'Final']

    def preformat_games(self):
        games_df = self.games_header.copy()
        games_df = self.merge_on_team(df=games_df, team_col='HOME_TEAM_ID')
        games_df = self.merge_on_team(df=games_df, team_col='VISITOR_TEAM_ID')

        games_df['HOME_TEAM_WINS'] = self.home_team_win(games_df)
        games_df['GAME_ID'] = self.format_game_id(games_df)
        games_df['GAME_DATE_EST'] = self.format_date(games_df)

        games_df = self.filter_game_no_nba_team(games_df)
        games_df = self.only_finished_game(games_df)

        games_df['GAME_ID'] = games_df['GAME_ID'].astype(int)
        games_df = games_df.drop_duplicates().reset_index(drop=True)

        return games_df

    def preformat_ranking(self):
        ranking = pd.concat([self.west_ranking, self.east_ranking])
        ranking['STANDINGSDATE'] = pd.to_datetime(ranking['STANDINGSDATE'])

        return ranking


from setuptools import setup, find_packages 


with open("README.md", "r", encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '1.0.6'
DESCRIPTION = 'NBA data Scrapper for stats analysis'

# Setting up the package
setup(
    name = "fu-scrapper",
    version = VERSION,
    author = 'Fujyn',
    author_email = "fujyn.contact@gmail.com",
    url = 'https://github.com/Endy02/fu-scrapper',
    project_urls={
        "Bug Tracker": "https://github.com/Endy02/fu-scrapper/issues",
    },
    description = DESCRIPTION,
    long_description_content_type = 'text/markdown',
    long_description=long_description,
    install_requires = ['pandas','numpy','requests','joblib'],
    python_requires = '>=3.7',
    keywords = ['python','sports','data-analysis','csv'],
    classifiers = [
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ],
    package_dir={"": "src"},
    packages=find_packages(where="src"),
)


import os
from time import time

import pandas as pd
from ..tools.tools import Tools


class Players():
    def __init__(self, url):
        self.tools = Tools(url)
        self.data_url = url

    def export_players(self):
        """
            Export players informations and global stats
        """
        try:
            # Initialize the timer
            t0 = time()
            # Url of the all players detailes per seasons
            url = 'https://stats.nba.com/stats/leaguedashplayerstats?College=&Conference=&Country=&DateFrom=&DateTo=&Division=&DraftPick=&DraftYear=&GameScope=&GameSegment=&Height=&LastNGames=0&LeagueID=00&Location=&MeasureType=Base&Month=0&OpponentTeamID=0&Outcome=&PORound=0&PaceAdjust=N&PerMode=Totals&Period=0&PlayerExperience=&PlayerPosition=&PlusMinus=N&Rank=N&Season=2021-22&SeasonSegment=&SeasonType=Regular+Season&ShotClockRange=&StarterBench=&TeamID=0&TwoWay=0&VsConference=&VsDivision=&Weight='

            players = self.tools.get_data(url, datasets_name=['LeagueDashPlayerStats'])
            players = players['LeagueDashPlayerStats']
            players_clean = self.__get_player_info(players)
                        
            if players is not None:
                players_clean.to_csv(self.data_url + 'players.csv')
                
            print('All Players export execution time : %.2fs'%(time()-t0))
            
        except Exception as e:
            raise e
    
    def __get_player_info(self, player_dataset):
        """
            Get all players personnal informations and merge it to current detail dataset
        """
        try:
            # Url to get Teams infos 
            url = 'https://stats.nba.com/stats/leaguedashplayerbiostats?College=&Conference=&Country=&DateFrom=&DateTo=&Division=&DraftPick=&DraftYear=&GameScope=&GameSegment=&Height=&LastNGames=0&LeagueID=00&Location=&Month=0&OpponentTeamID=0&Outcome=&PORound=0&PerMode=Totals&Period=0&PlayerExperience=&PlayerPosition=&Season=2021-22&SeasonSegment=&SeasonType=Regular+Season&ShotClockRange=&StarterBench=&TeamID=0&VsConference=&VsDivision=&Weight='
            players_details = self.tools.get_data(url, datasets_name=['LeagueDashPlayerBioStats'])
            players_details = players_details['LeagueDashPlayerBioStats']
            
            extract_fields = ['PLAYER_HEIGHT', 'PLAYER_HEIGHT_INCHES', 'PLAYER_WEIGHT', 'COLLEGE', 'COUNTRY', 'DRAFT_YEAR', 'DRAFT_ROUND', 'DRAFT_NUMBER', 'NET_RATING']
            
            for field in extract_fields:
                player_dataset[field] = player_dataset.merge(players_details, on="PLAYER_ID")[field]

            # return updated dataset
            return player_dataset
        except Exception as e:
            raise e
    

# NBA Url for players stats per season
# https://stats.nba.com/stats/leaguedashplayerstats?College=&Conference=&Country=&DateFrom=&DateTo=&Division=&DraftPick=&DraftYear=&GameScope=&GameSegment=&Height=&LastNGames=0&LeagueID=00&Location=&MeasureType=Base&Month=0&OpponentTeamID=0&Outcome=&PORound=0&PaceAdjust=N&PerMode=Totals&Period=0&PlayerExperience=&PlayerPosition=&PlusMinus=N&Rank=N&Season=2021-22&SeasonSegment=&SeasonType=Regular+Season&ShotClockRange=&StarterBench=&TeamID=0&TwoWay=0&VsConference=&VsDivision=&Weight=


# NBA Url for Players Bios
# https://stats.nba.com/stats/leaguedashplayerbiostats?College=&Conference=&Country=&DateFrom=&DateTo=&Division=&DraftPick=&DraftYear=&GameScope=&GameSegment=&Height=&LastNGames=0&LeagueID=00&Location=&Month=0&OpponentTeamID=0&Outcome=&PORound=0&PerMode=Totals&Period=0&PlayerExperience=&PlayerPosition=&Season=2021-22&SeasonSegment=&SeasonType=Regular+Season&ShotClockRange=&StarterBench=&TeamID=0&VsConference=&VsDivision=&Weight=


# NBA Url for Player scoreBoard per season
# https://stats.nba.com/stats/leaguegamelog?Counter=1000&DateFrom=&DateTo=&Direction=DESC&LeagueID=00&PlayerOrTeam=P&Season=2021-22&SeasonType=Regular+Season&Sorter=DATE
